@@ -1,4 +1,4 @@
-/* Copyright (c) 2004,2005, Colin O'Flynn <coflynn@newae.com>
+/* Copyright (c) 2004,2005,2006 Colin O'Flynn <coflynn@newae.com>
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iocanxx.h,v 1.1.2.1 2005/12/13 21:15:15 aesok Exp $ */
+/* $Id: iocanxx.h,v 1.1.2.3 2006/05/03 14:27:51 aesok Exp $ */
 
 /* This file is based largely on:
    - iom128.h by Peter Jansen (bit defines)
@@ -390,9 +390,12 @@
 #define CANIE1 _SFR_MEM8(0xDF)
 
 /* RegDef:  CAN Status Interrupt MOb Register*/
+/*
+ * WARNING: Do not apply the SIT8...SIT14 constants to bits in the CANSIT
+ * register.
+ */
+#define CANSIT  _SFR_MEM16(0xE0)
 #define CANSIT2 _SFR_MEM8(0xE0)
-
-/* RegDef:  CAN Status Interrupt MOb Register*/
 #define CANSIT1 _SFR_MEM8(0xE1)
 
 /* RegDef:  CAN Bit Timing Register 1*/
@@ -436,12 +439,16 @@
 #define CANCDMOB _SFR_MEM8(0xEF)
 
 /* RegDef:  CAN Identifier Tag Registers*/
+#define CANIDT  _SFR_MEM32(0xF0)
+
 #define CANIDT4 _SFR_MEM8(0xF0)
 #define CANIDT3 _SFR_MEM8(0xF1)
 #define CANIDT2 _SFR_MEM8(0xF2)
 #define CANIDT1 _SFR_MEM8(0xF3)
 
 /* RegDef:  CAN Identifier Mask Registers */
+#define CANIDM  _SFR_MEM32(0xF4)
+
 #define CANIDM4 _SFR_MEM8(0xF4)
 #define CANIDM3 _SFR_MEM8(0xF5)
 #define CANIDM2 _SFR_MEM8(0xF6)
