@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn22.h,v 1.5 2004/11/01 22:23:56 arcanum Exp $ */
+/* $Id: iotn22.h,v 1.8 2005/10/30 22:11:23 joerg_wunsch Exp $ */
 
 /* avr/iotn22.h - definitions for ATtiny22 */
 
@@ -58,7 +58,15 @@
 /* Data Register, Port B */
 #define PORTB	_SFR_IO8(0x18)
 
-/* 0x1C..0x1E EEPROM */
+/* EEPROM Control Register */
+#define EECR	_SFR_IO8(0x1C)
+
+/* EEPROM Data Register */
+#define EEDR	_SFR_IO8(0x1D)
+
+/* EEPROM Address Register */
+#define EEAR	_SFR_IO8(0x1E)
+#define EEARL	_SFR_IO8(0x1E)
 
 /* Watchdog Timer Control Register */
 #define WDTCR	_SFR_IO8(0x21)
@@ -93,8 +101,13 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0		_VECTOR(1)
-#define SIG_OVERFLOW0		_VECTOR(2)
+/* External Interrupt 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF0_vect		_VECTOR(2)
+#define SIG_OVERFLOW0			_VECTOR(2)
 
 #define _VECTORS_SIZE 6
 
@@ -155,6 +168,12 @@
 #define    PINB1   1
 #define    PINB0   0
 
+/* EEPROM Control Register */
+#define    EERIE   3
+#define    EEMWE   2
+#define    EEWE    1
+#define    EERE    0
+
 /* Constants */
 #define    RAMEND    0xDF
 #define    XRAMEND   0xDF
