@@ -30,7 +30,7 @@
 
 /* avr/sfr_defs.h - macros for accessing AVR special function registers */
 
-/* $Id: sfr_defs.h,v 1.14.2.1 2005/01/07 19:25:25 arcanum Exp $ */
+/* $Id: sfr_defs.h,v 1.16.2.2 2006/05/17 08:25:10 joerg_wunsch Exp $ */
 
 #ifndef _AVR_SFR_DEFS_H_
 #define _AVR_SFR_DEFS_H_ 1
@@ -41,14 +41,15 @@
    The \c <avr/sfr_defs.h> file is included by all of the \c <avr/ioXXXX.h>
    files, which use macros defined here to make the special function register
    definitions look like C variables or simple constants, depending on the
-   <tt>_SFR_ASM_COMPAT</tt> define.  Some examples from \c <avr/iom128.h> to
+   <tt>_SFR_ASM_COMPAT</tt> define.  Some examples from \c <avr/iocanxx.h> to
    show how to define such macros:
 
 \code
-#define PORTA _SFR_IO8(0x1b)
-#define TCNT1 _SFR_IO16(0x2c)
-#define PORTF _SFR_MEM8(0x61)
-#define TCNT3 _SFR_MEM16(0x88)
+#define PORTA   _SFR_IO8(0x02)
+#define EEAR    _SFR_IO16(0x21)
+#define UDR0    _SFR_MEM8(0xC6)
+#define TCNT3   _SFR_MEM16(0x94)
+#define CANIDT  _SFR_MEM32(0xF0)
 \endcode
 
    If \c _SFR_ASM_COMPAT is not defined, C programs can use names like
@@ -101,7 +102,7 @@
    If you do not define \c __SFR_OFFSET (so it will be 0x20 by default), all
    special register addresses are defined as memory addresses (so \c SREG is
    0x5f), and (if code size and speed are not important, and you don't like
-   the ugly #if above) you can always use lds/sts to access them.  But, this
+   the ugly \#if above) you can always use lds/sts to access them.  But, this
    will not work if <tt>__SFR_OFFSET</tt> != 0x20, so use a different macro
    (defined only if <tt>__SFR_OFFSET</tt> == 0x20) for safety:
 
@@ -116,6 +117,8 @@
 
 #ifdef __ASSEMBLER__
 #define _SFR_ASM_COMPAT 1
+#elif !defined(_SFR_ASM_COMPAT)
+#define _SFR_ASM_COMPAT 0
 #endif
 
 #ifndef __ASSEMBLER__
@@ -124,6 +127,7 @@
 
 #define _MMIO_BYTE(mem_addr) (*(volatile uint8_t *)(mem_addr))
 #define _MMIO_WORD(mem_addr) (*(volatile uint16_t *)(mem_addr))
+#define _MMIO_DWORD(mem_addr) (*(volatile uint32_t *)(mem_addr))
 #endif
 
 #if _SFR_ASM_COMPAT
@@ -140,6 +144,7 @@
 
 #define _SFR_MEM8(mem_addr) (mem_addr)
 #define _SFR_MEM16(mem_addr) (mem_addr)
+#define _SFR_MEM32(mem_addr) (mem_addr)
 #define _SFR_IO8(io_addr) ((io_addr) + __SFR_OFFSET)
 #define _SFR_IO16(io_addr) ((io_addr) + __SFR_OFFSET)
 
@@ -158,6 +163,7 @@
 
 #define _SFR_MEM8(mem_addr) _MMIO_BYTE(mem_addr)
 #define _SFR_MEM16(mem_addr) _MMIO_WORD(mem_addr)
+#define _SFR_MEM32(mem_addr) _MMIO_DWORD(mem_addr)
 #define _SFR_IO8(io_addr) _MMIO_BYTE((io_addr) + 0x20)
 #define _SFR_IO16(io_addr) _MMIO_WORD((io_addr) + 0x20)
 
@@ -171,6 +177,7 @@
 
 #define _SFR_BYTE(sfr) _MMIO_BYTE(_SFR_ADDR(sfr))
 #define _SFR_WORD(sfr) _MMIO_WORD(_SFR_ADDR(sfr))
+#define _SFR_DWORD(sfr) _MMIO_DWORD(_SFR_ADDR(sfr))
 
 /** \name Bit manipulation */
 
