@@ -1,5 +1,5 @@
 /* Copyright (c) 2002, 2004 Marek Michalkiewicz
-   Copyright (c) 2005 Eric B. Weddington
+   Copyright (c) 2005, 2006 Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.9.2.2 2005/01/10 22:44:22 arcanum Exp $ */
+/* $Id: wdt.h,v 1.22.2.8 2006/09/13 20:41:41 arcanum Exp $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -41,7 +41,7 @@
 #include <avr/io.h>
 #include <stdint.h>
 
-/** \defgroup avr_watchdog Watchdog timer handling
+/** \defgroup avr_watchdog <avr/wdt.h>: Watchdog timer handling
     \code #include <avr/wdt.h> \endcode
 
     This header file declares the interface to some inline macros
@@ -55,7 +55,38 @@
 
     \note Depending on the fuse configuration of the particular
     device, further restrictions might apply, in particular it might
-    be disallowed to turn off the watchdog timer. */
+    be disallowed to turn off the watchdog timer.
+
+    Note that for newer devices (ATmega88 and newer, effectively any
+    AVR that has the option to also generate interrupts), the watchdog
+    timer remains active even after a system reset (except a power-on
+    condition), using the fastest prescaler value (approximately 15
+    ms).  It is therefore required to turn off the watchdog early
+    during program startup, the datasheet recommends a sequence like
+    the following:
+
+    \code
+    #include <stdint.h>
+    #include <avr/wdt.h>
+
+    uint8_t mcusr_mirror;
+
+    void get_mcusr(void) \
+      __attribute__((naked)) \
+      __attribute__((section(".init3")));
+    void get_mcusr(void)
+    {
+      mcusr_mirror = MCUSR;
+      MCUSR = 0;
+      wdt_disable();
+    }
+    \endcode
+
+    Saving the value of MCUSR in \c mcusr_mirror is only needed if the
+    application later wants to examine the reset source, but clearing
+    in particular the watchdog reset flag before disabling the
+    watchdog is required, according to the datasheet.
+*/
 
 /**
    \ingroup avr_watchdog
@@ -65,13 +96,16 @@
 
 #define wdt_reset() __asm__ __volatile__ ("wdr")
 
-#if defined(__AVR_ATtiny2313__) || defined(__AVR_ATmega48__) \
-|| defined(__AVR_ATmega88__) || defined(__AVR_ATmega168__)
-#define _WD_CONTROL_REG     WDTCSR
-#define _WD_PS3_MASK        _BV(WDP3)
+#if defined(WDP3)
+# define _WD_PS3_MASK       _BV(WDP3)
 #else
-#define _WD_CONTROL_REG     WDTCR
-#define _WD_PS3_MASK        0x00
+# define _WD_PS3_MASK       0x00
+#endif /* WDP3 */
+
+#if defined(WDTCSR)
+#  define _WD_CONTROL_REG     WDTCSR
+#else
+#  define _WD_CONTROL_REG     WDTCR
 #endif
 
 #if defined(WDTOE)
@@ -81,9 +115,26 @@
 #endif
 
 
-#if defined (__AVR_ATmega169__) || defined(__AVR_AT90CAN128__) \
+#if defined(__AVR_AT90CAN128__) \
+|| defined(__AVR_AT90CAN32__) || defined(__AVR_AT90CAN64__) \
+|| defined(__AVR_AT90USB646__) || defined(__AVR_AT90USB647__) \
+|| defined(__AVR_AT90USB1286__) || defined(__AVR_AT90USB1287__) \
 || defined(__AVR_ATmega48__) || defined(__AVR_ATmega88__) \
-|| defined(__AVR_ATmega168__)
+|| defined(__AVR_ATmega164P__) \
+|| defined(__AVR_ATmega165__) || defined(__AVR_ATmega165P__) \
+|| defined(__AVR_ATmega168__) \
+|| defined(__AVR_ATmega169__) || defined(__AVR_ATmega169P__) \
+|| defined(__AVR_ATmega324P__) \
+|| defined(__AVR_ATmega325__) || defined(__AVR_ATmega3250__) \
+|| defined(__AVR_ATmega329__) || defined(__AVR_ATmega3290__) \
+|| defined(__AVR_ATmega406__) \
+|| defined(__AVR_ATmega640__) \
+|| defined(__AVR_ATmega644__) || defined(__AVR_ATmega644P__) \
+|| defined(__AVR_ATmega645__) || defined(__AVR_ATmega6450__) \
+|| defined(__AVR_ATmega649__) || defined(__AVR_ATmega6490__) \
+|| defined(__AVR_ATmega1280__) || defined(__AVR_ATmega1281__) \
+|| defined(__AVR_ATmega2560__) || defined(__AVR_ATmega2561__) \
+|| defined(__AVR_AT90PWM2__) || defined(__AVR_AT90PWM3__)
  
 #define _wdt_write(value)   \
     __asm__ __volatile__ (  \
@@ -104,6 +155,7 @@
 #define wdt_disable() \
 __asm__ __volatile__ (  \
     "in __tmp_reg__, __SREG__" "\n\t" \
+    "cli" "\n\t" \
     "sts %0, %1" "\n\t" \
     "sts %0, __zero_reg__" "\n\t" \
     "out __SREG__,__tmp_reg__" "\n\t" \
@@ -142,6 +194,7 @@ __asm__ __volatile__ (  \
 #define wdt_disable() \
 __asm__ __volatile__ (  \
     "in __tmp_reg__, __SREG__" "\n\t" \
+     "cli" "\n\t" \
     "out %0, %1" "\n\t" \
     "out %0, __zero_reg__" "\n\t" \
     "out __SREG__,__tmp_reg__" "\n\t" \
@@ -178,7 +231,8 @@ __asm__ __volatile__ (  \
    a negligible change.
 
    Possible timeout values are: 15 ms, 30 ms, 60 ms, 120 ms, 250 ms,
-   500 ms, 1 s, 2 s.  Symbolic constants are formed by the prefix
+   500 ms, 1 s, 2 s.  (Some devices also allow for 4 s and 8 s.)
+   Symbolic constants are formed by the prefix
    \c WDTO_, followed by the time.
 
    Example that would select a watchdog timer expiry of approximately
@@ -217,20 +271,37 @@ __asm__ __volatile__ (  \
     See \c WDT0_15MS */
 #define WDTO_2S     7
 
-#if defined(__AVR_ATtiny2313__) || defined(__AVR_ATmega48__) || \
-defined(__AVR_ATmega88__) || defined(__AVR_ATmega168__)
+#if defined(__DOXYGEN__) || defined(WDP3)
 
 /** \ingroup avr_watchdog
     See \c WDT0_15MS
-    Note: This is only available on the ATtiny2313, ATmega48, ATmega88,
-    and the ATmega168.
+    Note: This is only available on the 
+    ATtiny2313, 
+    ATtiny24, ATtiny44, ATtiny84, 
+    ATtiny25, ATtiny45, ATtiny85, 
+    ATtiny261, ATtiny461, ATtiny861, 
+    ATmega48, ATmega88, ATmega168,
+    ATmega164P, ATmega324P, ATmega644P, ATmega644,
+    ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
+    ATmega406,
+    AT90PWM2, AT90PWM3,
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
     */
 #define WDTO_4S     8
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS 
-    Note: This is only available on the ATtiny2313, ATmega48, ATmega88,
-    and the ATmega168.
+    See \c WDT0_15MS
+    Note: This is only available on the 
+    ATtiny2313, 
+    ATtiny24, ATtiny44, ATtiny84, 
+    ATtiny25, ATtiny45, ATtiny85, 
+    ATtiny261, ATtiny461, ATtiny861, 
+    ATmega48, ATmega88, ATmega168,
+    ATmega164P, ATmega324P, ATmega644P, ATmega644,
+    ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
+    ATmega406,
+    AT90PWM2, AT90PWM3,
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
     */
 #define WDTO_8S     9
 
