@@ -32,7 +32,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: math.h,v 1.5 2004/11/10 20:07:12 arcanum Exp $ */
+/* $Id: math.h,v 1.9 2005/11/11 21:45:36 aesok Exp $ */
 
 /*
    math.h - mathematical functions
@@ -48,7 +48,7 @@
 #ifndef __MATH_H
 #define __MATH_H
 
-/** \defgroup avr_math Mathematics
+/** \defgroup avr_math <math.h>: Mathematics
     \code #include <math.h> \endcode
 
     This header file declares basic mathematics constants and
@@ -72,7 +72,7 @@
    The square root of 2. */
 #define M_SQRT2 1.4142135623730950488016887
 
-#ifndef DOXYGEN
+#ifndef __DOXYGEN__
 
 #ifndef __ATTR_CONST__
 #define __ATTR_CONST__ __attribute__((__const__))
@@ -201,7 +201,7 @@ extern double ldexp(double __x, int __exp) __ATTR_CONST__;
 
      The exp() function returns the exponential value of \c x.
   */
-extern double exp(double _x) __ATTR_CONST__;
+extern double exp(double __x) __ATTR_CONST__;
 
   /**
      \ingroup avr_math
@@ -280,7 +280,7 @@ extern double log(double __x) __ATTR_CONST__;
   /**
      \ingroup avr_math
 
-     The log() function returns the logarithm of argument \c x to base 10.
+     The log10() function returns the logarithm of argument \c x to base 10.
 
      If the argument is less than or equal 0, a domain error will occur.
    */
@@ -318,15 +318,6 @@ extern int isinf(double __x) __ATTR_CONST__;
      This function does not belong to the C standard definition.
   */
 extern double square(double __x) __ATTR_CONST__;
-  /**
-     \ingroup avr_math
-
-     The function inverse() returns <tt>1 / x</tt>.
-
-     \note
-     This function does not belong to the C standard definition.
-  */
-extern double inverse(double) __ATTR_CONST__;
 
 #ifdef __cplusplus
 }
